@@ -6,16 +6,20 @@ from tracardi_track_client.model.tracker_payload import TrackerPayload
 import requests
 
 
-def track(callback_url, source_id, profile_id, session_id, event_type, properties, context=None):
+def track(callback_url, source_id, profile_id, session_id, event_type, properties, context=None, request=None):
     if context is None:
         context = {}
 
+    if request is None:
+        request = {}
+
     if source_id is not None:
 
         payload = TrackerPayload(
             source=Entity(id=source_id),
             session=Entity(id=session_id) if session_id is not None else None,
-            profile=Entity(id=profile_id) if profile_id is not None else None
+            profile=Entity(id=profile_id) if profile_id is not None else None,
+            request=request
         )
 
         event = EventPayload(type=event_type, properties=properties)
@@ -42,5 +46,6 @@ if __name__ == "__main__":
         session_id=None,
         event_type="test",
         properties={},
-        context={"aaa": 1}
+        context={"aaa": 1},
+        request={"test": 1}
     )
